% Tabulates MC results (in the format of the tables in the supplement)
% Generates four csv files to save the results for rho, beta, intercept, 
% and number of boundary solutions, respectively
clear all;
close all;
date_string = '122019';
fdir = '.';

option = 3;  % Estimation Option, see main_MC.m for details
rhoset = [0.2,0.5,0.75];
Nset = [100, 300, 500, 1000];
flag_NormalErr = 1;
flag_HetVar = 1;  
flag_SARX = 1;
flag_Wx = 0;
flag_expodecay = 0;
deltax = 1;
if flag_expodecay == 0
    deltaset = [0,0.25,0.5,0.75,0.95,1];
    num_domi = 1;
elseif flag_expodecay == 1
    q_decay = 0.9;
    deltaset = [0]; % this is a dummy and not used
end  

if flag_NormalErr==1
    err_string = 'normal';
elseif flag_NormalErr==0
    err_string = 'chi2';
end  
if flag_HetVar==1
    err_string = [err_string,'_HetVar'];
end
if flag_SARX==1
    model_string = 'SARX';
elseif flag_SARX==0
    model_string = 'SAR';
end
if flag_Wx==1 && flag_SARX==0
    error('Wrong flag combinations!');
end

lenN = length(Nset);
lendel = length(deltaset);
lenrho = length(rhoset);
bias_rho = zeros(lendel,lenN,lenrho);
rmse_rho = zeros(lendel,lenN,lenrho);
siz_rho = zeros(lendel,lenN,lenrho);
pow_rho = zeros(lendel,lenN,lenrho);
bias_inpt = zeros(lendel,lenN,lenrho);
rmse_inpt = zeros(lendel,lenN,lenrho);
siz_inpt = zeros(lendel,lenN,lenrho);
pow_inpt = zeros(lendel,lenN,lenrho);
if flag_SARX==1
    bias_beta = zeros(lendel,lenN,lenrho);
    rmse_beta = zeros(lendel,lenN,lenrho);
    siz_beta = zeros(lendel,lenN,lenrho);
    pow_beta = zeros(lendel,lenN,lenrho);
end
num_boundary_mtx = zeros(lendel,lenN,lenrho);

for rhoi = 1:lenrho
    for n = 1:length(Nset)
        for del = 1:length(deltaset)
            rho = rhoset(rhoi);
            N = Nset(n);
            delta = deltaset(del);

        if flag_expodecay==0
            if num_domi==1
                if flag_SARX==1
                    fpath = [fdir,'\results_SARX_',date_string,'\'];
                    fname =  [fpath, 'results_',date_string,'_',model_string,'_',err_string,'_',num2str(option),'_',...
                        num2str(rho),'_',num2str(N),'_',num2str(delta),'.mat'];
                    if flag_Wx==1
                        fpath = [fdir,'\results_SARX_Wx_',date_string,'\'];
                        fname = [fpath, 'results_',date_string,'_',model_string,'_',err_string,'_',num2str(option),'_',...
                        num2str(rho),'_',num2str(N),'_',num2str(delta),'_Wx_',num2str(deltax),'.mat'];                  
                    end                
                elseif flag_SARX==0
                    fpath = [fdir,'\results_SAR_',date_string,'\'];
                    fname =  [fpath,'results_',date_string,'_',model_string,'_',err_string,'_',num2str(option),'_',...
                        num2str(rho),'_',num2str(N),'_',num2str(delta),'.mat'];
                end
            elseif num_domi==2
                    fpath = [fdir,'\results_SARX_2domi_',date_string,'\'];
                    fname =  [fpath,'results_',date_string,'_',model_string,'_',err_string,'_',num2str(option),'_',...
                        num2str(rho),'_',num2str(N),'_',num2str(delta),'.mat'];
            end
        elseif flag_expodecay==1
            fpath = [fdir,'\results_SARX_expodecay_',date_string,'\'];
            fname = [fpath,'results_',date_string,'_',model_string,'_',err_string,'_',num2str(option),'_',...
                        num2str(rho),'_',num2str(N),'_expodecay_',num2str(q_decay),'.mat'];
        end
            result = load(fname, 'results');
            out = result.results;
            
            bias_rho(del,n,rhoi) = out(1,1);
            rmse_rho(del,n,rhoi) = out(2,1);
            siz_rho(del,n,rhoi) = out(3,1);
            pow_rho(del,n,rhoi) = out(4,1);
            
            bias_inpt(del,n,rhoi) = out(1,2);
            rmse_inpt(del,n,rhoi) = out(2,2);
            siz_inpt(del,n,rhoi) = out(3,2);
            pow_inpt(del,n,rhoi) = out(4,2);
            
            if flag_SARX==1
                bias_beta(del,n,rhoi) = out(1,3);
                rmse_beta(del,n,rhoi) = out(2,3);
                siz_beta(del,n,rhoi) = out(3,3);
                pow_beta(del,n,rhoi) = out(4,3);
            end
            
            load(fname, 'num_boundary');
            num_boundary_mtx(del,n,rhoi)= num_boundary;           
        end
    end
end

table_rho = [];
for i = 1:lenrho
    tab_rhoi= 100*[[bias_rho(:,:,i) rmse_rho(:,:,i)  siz_rho(:,:,i) pow_rho(:,:,i)]; zeros(1,lenN*4)];
    table_rho = [table_rho;tab_rhoi];
end
fname_rho =  strcat(fpath,'outtab_',date_string,'_',model_string,'_',err_string,'_',num2str(option),'_rho.csv');
csvwrite(fname_rho,table_rho,0,0);

table_inpt = [];
for i = 1:lenrho
    tab_inpti= 100*[[bias_inpt(:,:,i) rmse_inpt(:,:,i)  siz_inpt(:,:,i) pow_inpt(:,:,i)]; zeros(1,lenN*4)];
    table_inpt = [table_inpt;tab_inpti];
end
fname_inpt =  strcat(fpath,'outtab_',date_string,'_',model_string,'_',err_string,'_',num2str(option),'_inpt.csv');
csvwrite(fname_inpt,table_inpt,0,0);

if flag_SARX==1
    table_beta = [];
    for i = 1:lenrho
        tab_betai= 100*[[bias_beta(:,:,i) rmse_beta(:,:,i)  siz_beta(:,:,i) pow_beta(:,:,i)]; zeros(1,lenN*4)];
        table_beta = [table_beta;tab_betai];
    end
    fname_beta =  strcat(fpath,'outtab_',date_string,'_',model_string,'_',err_string,'_',num2str(option),'_beta.csv');
    csvwrite(fname_beta,table_beta,0,0);
end

tab_boundary = [];
for i = 1: lenrho
    tab_boundary = [tab_boundary; num_boundary_mtx(:,:,i);9999*ones(1,lenN)];
end
fname_boundary = strcat(fpath,'outtab_',date_string,'_',model_string,'_',err_string,'_',num2str(option),'_boundary.csv');
csvwrite(fname_boundary,tab_boundary,0,0);  
