function [Dt,Sigmag,covmtx]=GMM_multiP_var_SARX_iid(parm,Y,L,Q,P,Wg,W,N,k,longv)
% Computes GMM variance assuming homoskedastic errors
% longv==1: uses general sandwich formula
% longv==0: uses optimal GMM variance formula

rhohat = parm(1);
betahat = parm(2:k+1);
X = L(:,2:end);
q = size(Q,2);
nP = size(P,3);
S = speye(N)-rhohat*W;
G = W/S;

% Construct D matrix
Dt = zeros(k+1,q+nP);   % D transpose
Dt(1,nP+1:q+nP) = (G*X*betahat)'*Q;
Dt(2:k+1,nP+1:q+nP) = X'*Q;

% Construct variance of moments: Sigmag
ehatN = Y-L*parm;
sige2hat = ehatN'*ehatN/N;
gamma2 = sum(ehatN.^4)/N - 3*sige2hat^2; 
mu3 = sum(ehatN.^3)/N;
omega = zeros(N,nP);
Delta1 = zeros(N*N,nP); 
Delta2 = zeros(N*N,nP);
for j = 1:nP
    omega(:,j) = diag(P(:,:,j));
    Pt = P(:,:,j)';
    Ps = P(:,:,j)+Pt;
    Delta1(:,j) = Pt(:); 
    Delta2(:,j) = Ps(:);
    Dt(1,j) = sige2hat* sum(sum(G.*Ps));
end
Dt = Dt/N;
D = Dt';     
Delta = Delta1'*Delta2;
V1 = zeros(q+nP,q+nP);
V1(1:nP,1:nP) = gamma2.*(omega'*omega);
V1(nP+1:q+nP,1:nP) = mu3.*(Q'*omega);
V1(1:nP,nP+1:q+nP) = V1(nP+1:q+nP,1:nP)';

V2 = zeros(q+nP,q+nP);
V2(1:nP,1:nP) = sige2hat^2.*Delta;
V2(nP+1:q+nP,nP+1:q+nP) = sige2hat.*(Q'*Q);
Sigmag = (V1+V2)/N;

if longv==1
    DWg = Dt*Wg;
    WgD = Wg*D;
    DWgD = DWg*D;
    mid = DWg*Sigmag*WgD;
    covmtx = pinv(DWgD)*mid*pinv(DWgD)/N;
elseif longv==0
    tmp = Dt*pinv(Sigmag)*D;
    covmtx = pinv(tmp)/N;
end

end